@@ -4,7 +4,7 @@ from cprint.config import CONTANT_DICT
 from forbiddenfruit import curse
 
 STYLE_CONFIG = getshow_config(1)
-PATTERN1 = re.compile(r'(@(\d+)){\d+.*?}')
+PATTERN = re.compile(r'(@(\d+)){\d+.*?}')
 
 def cp(text: str, style_id: int) -> str:
     """
@@ -37,35 +37,12 @@ def cf(text: str) -> str:
         replace_text, style_id = match.groups()
         return match.group().replace(replace_text, STYLE_CONFIG[int(style_id)]) + "\033[0;0m"
 
-    return re.sub(PATTERN1, pr_march, text)
+    for mark, mark_fun in CONTANT_DICT.items():
+        text = text.replace(mark, mark_fun())
+
+    return re.sub(PATTERN, pr_march, text)
 
 def cformat(self, *args, **kwargs):
     return cf(self).format(*args, **kwargs)
 
-curse(str, "cformat", cformat)
-
-def cfd(text: str) -> str:
-    """
-    Colorful Format
-    文档:
-        使用style_id格式化字符串, 相比cf函数多了一些替换日期时间常量的功能
-    参数:
-        text: str
-            需要格式化的字符串
-    返回:
-        返回格式化好的字符串
-    """
-    def pr_march(match):
-
-        replace_text, style_id = match.groups()
-        return match.group().replace(replace_text, STYLE_CONFIG[int(style_id)]) + "\033[0;0m"
-
-    for mark, mark_fun in CONTANT_DICT.items():
-        text = text.replace(mark, mark_fun())
-
-    return re.sub(PATTERN1, pr_march, text)
-
-def cformatd(self, *args, **kwargs):
-    return cfd(self).format(*args, **kwargs)
-
-curse(str, "cformatd", cformatd)
\ No newline at end of file
+curse(str, "cformat", cformat)
\ No newline at end of file
